OC.L10N.register(
    "text",
    {
    "Text" : "Text",
    "Use current version" : "Použít stávající verzi",
    "Use the saved version" : "Použít uloženou verzi",
    "Network connection error: Could not connect to the document" : "Chyba nastavení sítě: nedaří se připojit k dokumentu",
    "Retry" : "Zkusit znovu",
    "Last save {lastSave}" : "Poslední uložení {lastSave}",
    "Unpushed changes" : "Neodeslané změny",
    "Unsaved changes" : "Neuložené změny",
    "Enter your name so other users can see who is editing" : "Zadejte své jméno aby ostatní viděli, kdo upravuje",
    "Edit guest name" : "Upravit jméno hosta",
    "Save guest name" : "Uložit jméno hosta",
    "Insert image" : "Vložit obrázek",
    "Add link" : "Přidat odkaz",
    "_and %n other editor_::_and %n other editors_" : ["a %n další editor","a %n další editoři/editorky","a %n další editorů/editorek","a %n další editoři/editorky"],
    "Show image" : "Zobrazit obrázek",
    "Show file" : "Zobrazit soubor",
    "New text document" : "Nový textový dokument",
    "Edit" : "Upravit",
    "Undo" : "Zpět",
    "Redo" : "Zopakovat",
    "Bold" : "Tučné",
    "Italic" : "Skloněné",
    "Strikethrough" : "Přeškrtnuté",
    "Paragraph" : "Odstavec",
    "Headings" : "Nadpisy",
    "Heading 1" : "Nadpis 1",
    "Heading 2" : "Nadpis 2",
    "Heading 3" : "Nadpis 3",
    "Heading 4" : "Nadpis 4",
    "Heading 5" : "Nadpis 5",
    "Heading 6" : "Nadpis 6",
    "Unordered list" : "Neuspořádaný seznam",
    "Ordered list" : "Uspořádaný seznam",
    "Code block" : "Blok kódu",
    "New text document.md" : "Nový textový dokument.md"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
